# Zet Changelog

## 1.2.0 (2025-10-06)

* Add `--json` option to all commands for outputting JSON data
* Add `stops --name` option for filtering stops by name

## 1.1.0 (2025-07-12)

* Add `trip-stops` command
* Add `trips --route` option
* Add `route-trips --direction` option
* Handle HTTP errors

## 1.0.0 (2025-07-10)

* Initial release
